==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.j(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetRef", "(w:Target,wf:Target)DataRef");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("PropertyPath", "String");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
            a.aa("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", () => new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription());
            a.z("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetRef", "(w:Target,wf:Target)DataRef");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("PropertyPath", "String");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", () => new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription());
            a.ab("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
})();
